@@ -30,6 +30,7 @@ class Character:
         biography: str = None,
         classs: dict = None,
         class_name: str = None,
+        class_index: str = None,
         class_levels: list = None,
         level: int = 1,
         experience: int = 0,
@@ -54,11 +55,13 @@ class Character:
         skills_intelligence: dict = None,
         skills_charisma: dict = None,
         inventory: list = None,
-        invsize: int = None,
         prof_bonus: int = 0,
         ability_score_bonus: int = 0,
         class_features: dict = None,
         class_spellcasting: dict = None,
+        class_features_enabled: list = None,
+        spellcasting_stat: str = None,
+        player_options: dict = None,
     ):
         """
         Typical Arguments:
@@ -85,6 +88,9 @@ class Character:
         self.gender = gender
         self.description = description
         self.biography = biography
+        self.player_options = (
+            player_options if player_options is not None else {"starting_equipment": []}
+        )
 
         self.alignment = alignment
         if self.alignment is not None:
@@ -95,10 +101,14 @@ class Character:
 
         self.wealth = wealth
         self.class_name = class_name
+        self.class_index = class_index
         self.class_levels = class_levels if class_levels is not None else []
         self.prof_bonus = prof_bonus
         self.ability_score_bonus = ability_score_bonus
         self.class_features = class_features if class_features is not None else {}
+        self.class_features_enabled = (
+            class_features_enabled if class_features_enabled is not None else []
+        )
         self.class_spellcasting = (
             class_spellcasting if class_spellcasting is not None else {}
         )
@@ -133,6 +143,7 @@ class Character:
         self.spells_known = spells_known
         self.spells_prepared = spells_prepared
         self.spell_slots = spell_slots
+        self.spellcasting_stat = spellcasting_stat
 
         if skills_charisma is None:
             self.skills_charisma = {
@@ -178,9 +189,7 @@ class Character:
         else:
             self.skills_strength = skills_strength
 
-        # Inventory (currently primitive)
         self.inventory = inventory if inventory is not None else []
-        self.invsize = len(self.inventory)
 
         self.classs = classs
 
@@ -239,6 +248,7 @@ class Character:
         self.__class = new_class
         if new_class is not None:
             self.class_name = new_class["name"]
+            self.class_index = new_class["index"]
             self.hd = new_class["hit_die"]
 
             # create dict such as { "all-armor": {"name": "All armor", "type": "Armor"} }
@@ -253,10 +263,32 @@ class Character:
                 saving_throw["name"] for saving_throw in new_class["saving_throws"]
             ]
 
-            for item in SRD(new_class["starting_equipment"])["starting_equipment"]:
+            starting_equipment = SRD(new_class["starting_equipment"])
+            for item in starting_equipment["starting_equipment"]:
                 for i in range(item["quantity"]):
                     self.giveItem(SRD(item["equipment"]["url"]))
 
+            self.player_options["starting_equipment"] = []
+            for item_option in starting_equipment["starting_equipment_options"]:
+                options = []
+                if hasattr(item_option["from"], "get"):
+                    options.append(
+                        item_option["from"][list(item_option["from"].keys())[0]]["name"]
+                    )
+                else:
+                    for option in item_option["from"]:
+                        if "equipment_category" in option:
+                            options.append(option["equipment_category"]["name"])
+                        elif "equipment_option" in option:
+                            options.append(
+                                f'{"%s " % option["equipment_option"]["choose"] if option["equipment_option"]["choose"] != 1 else ""}{option["equipment_option"]["from"]["equipment_category"]["name"]}'
+                            )
+                        elif "equipment" in option:
+                            options.append(option["equipment"]["name"])
+                self.player_options["starting_equipment"].append(
+                    f"choose {item_option['choose']} from {', '.join(options)}"
+                )
+
             self.class_levels = SRD(new_class["class_levels"])
             if "spellcasting" in new_class:
                 self.spellcasting_stat = SRD(new_class["spellcasting"])[
@@ -281,6 +313,8 @@ class Character:
             self.prof_bonus = data.get("prof_bonus", self.prof_bonus)
             for feat in data["features"]:
                 self.class_features[feat["index"]] = SRD(feat["url"])
+            while len(self.class_features_enabled) < len(self.class_features):
+                self.class_features_enabled.append(True)
             self.class_spellcasting = data.get("spellcasting", self.class_spellcasting)
 
     @property
@@ -292,21 +326,11 @@ class Character:
         self._level = new_level
         self.applyClassLevel()
 
-    # Inventory and Inventory management (Primitive)
-    def getInventorySize(self):
-        self.invsize = len(self.inventory)
-        return self.invsize
-
-    def updateInventory(self):
-        self.invsize = len(self.inventory)
-
     def giveItem(self, item):
         self.inventory.append(item)
-        self.updateInventory()
 
     def removeItem(self, item):
         self.inventory.remove(item)
-        self.updateInventory()
 
     def giveWealth(self, amount):
         """
